@@ -1,5 +1,5 @@
 /************************************************************
-* Copyright (C) 2006-2007 Masahiko SAWAI All Rights Reserved. 
+* Copyright (C) 2006-2008 Masahiko SAWAI All Rights Reserved. 
 ************************************************************/
 
 #include "wiiremote.h"
@@ -615,13 +615,21 @@ WRMT_Init()
 void
 WRMT_Quit()
 {
+	DebugLog("Hello\n");
+
 	WRMT_Impl_Quit();
+
+	DebugLog("Bye\n");
 }
 
 void
 WRMT_Sleep(int ms)
 {
+	DebugLog("Hello\n");
+
 	WRMT_Impl_Sleep(ms);
+
+	DebugLog("Bye\n");
 }
 
 void
@@ -632,34 +640,36 @@ WRMT_Update()
 
 	do
 	{
-		rc = WRMT_Poll(NULL);
+		rc = WRMT_Poll();
 	}
 	while (rc == WRMT_IO_SUCCESS);
 	
 	DebugLog("Bye\n");
 }
 
-WRMT_IOReturn
-WRMT_Poll(int *updated_device_index_pointer)
+int
+WRMT_Poll()
 {
-	WRMT_IOReturn result;
+	int result;
+	WRMT_IOReturn rc;
 	WRMT_WiiRemote *wiiRemote;
 	int updated_device_index;
 	DebugLog("Hello\n");
 
 	/* Polling devices*/
-	result = WRMT_Impl_Poll(&updated_device_index);
+	rc = WRMT_Impl_Poll(&updated_device_index);
 
 	/* Update device status*/
-	if(result == WRMT_IO_SUCCESS)
+	if(rc == WRMT_IO_SUCCESS)
 	{
 		wiiRemote = &(wiiRemoteList[updated_device_index]);
 		WRMT_WiiRemote_ParseReport(wiiRemote);
 
-		if (updated_device_index_pointer != NULL)
-		{
-			*updated_device_index_pointer = updated_device_index;
-		}
+		result = updated_device_index;
+	}
+	else
+	{
+		result = rc;
 	}
 
 	DebugLog("Bye\n");
@@ -743,7 +753,7 @@ WRMT_WiiRemote_IsEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type)
 	WRMT_WiiRemote_Invaliant(self);
 	DebugLog("Hello type == %d\n", type);
 
-	result =  self->function_flag[type];
+	result = self->function_flag[type];
 
 	DebugLog("Bye result == %d\n", result);
 	WRMT_WiiRemote_Invaliant(self);
@@ -751,7 +761,8 @@ WRMT_WiiRemote_IsEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type)
 }
 
 void
-WRMT_WiiRemote_SetEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type, int value)
+WRMT_WiiRemote_SetEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type,
+	int value)
 {
 	assert(type >= 0 && type < WRMT_NUMBER_OF_FUNCTIONS);
 	assert(value == 0 || value == 1);
